package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcJmInfo;
import com.ruoyi.szxc.domain.SzxcOffRecard;
import com.ruoyi.szxc.mapper.SzxcJmInfoMapper;
import com.ruoyi.szxc.mapper.SzxcOffRecardMapper;
import com.ruoyi.szxc.service.ISzxcOffRecardService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 注销登记记录Service业务层处理
 * 
 * @author hs
 * @date 2024-03-20
 */
@Service
public class SzxcOffRecardServiceImpl implements ISzxcOffRecardService 
{
    @Resource
    private SzxcOffRecardMapper szxcOffRecardMapper;
    @Resource
    private SzxcJmInfoMapper szxcJmInfoMapper;

    /**
     * 查询注销登记记录
     * 
     * @param id 注销登记记录主键
     * @return 注销登记记录
     */
    @Override
    public SzxcOffRecard selectSzxcOffRecardById(Long id)
    {
        return szxcOffRecardMapper.selectSzxcOffRecardById(id);
    }

    /**
     * 查询注销登记记录列表
     * 
     * @param szxcOffRecard 注销登记记录
     * @return 注销登记记录
     */
    @Override
    public List<SzxcOffRecard> selectSzxcOffRecardList(SzxcOffRecard szxcOffRecard)
    {
        return szxcOffRecardMapper.selectSzxcOffRecardList(szxcOffRecard);
    }

    /**
     * 新增注销登记记录
     * 
     * @param szxcOffRecard 注销登记记录
     * @return 结果
     */
    @Override
    @Transactional
    public int insertSzxcOffRecard(SzxcOffRecard szxcOffRecard)
    {
        //修改居民信息   注销状态
        try {
            SzxcJmInfo  jmInfo = new SzxcJmInfo();
            jmInfo.setId(szxcOffRecard.getJmId());
            jmInfo.setOff("1");
            szxcJmInfoMapper.updateSzxcJmInfo(jmInfo);
            szxcOffRecard.setCreateTime(DateUtils.getNowDate());
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
        return szxcOffRecardMapper.insertSzxcOffRecard(szxcOffRecard);
    }

    /**
     * 修改注销登记记录
     * 
     * @param szxcOffRecard 注销登记记录
     * @return 结果
     */
    @Override
    public int updateSzxcOffRecard(SzxcOffRecard szxcOffRecard)
    {
        szxcOffRecard.setUpdateTime(DateUtils.getNowDate());
        return szxcOffRecardMapper.updateSzxcOffRecard(szxcOffRecard);
    }

    /**
     * 批量删除注销登记记录
     * 
     * @param ids 需要删除的注销登记记录主键
     * @return 结果
     */
    @Override
    public int deleteSzxcOffRecardByIds(Long[] ids)
    {
        return szxcOffRecardMapper.deleteSzxcOffRecardByIds(ids);
    }

    /**
     * 删除注销登记记录信息
     * 
     * @param id 注销登记记录主键
     * @return 结果
     */
    @Override
    public int deleteSzxcOffRecardById(Long id)
    {
        return szxcOffRecardMapper.deleteSzxcOffRecardById(id);
    }
}
